@@ -25,7 +25,7 @@ from typeguard import typechecked
 from urllib3.exceptions import HTTPError
 
 from . import __version__
-from .access import delete_jwt, get_previous_jwt, restore_previous_jwt, save_jwt
+from .access import delete_jwt, get_previous_jwt, restore_previous_jwt, save_jwt, AUTH_ENDPOINT
 from .queries import *
 from .util import HubException, hub_authenticated, timer
 
@@ -34,7 +34,6 @@ from .util import HubException, hub_authenticated, timer
 
 HUB_BASE_URL = "https://data.academic.osisoft.com"
 REGISTRATION_URL = "https://academic.osisoft.com/register"
-AUTH_ENDPOINT = "https://academichub-auth.azurewebsites.net/auth"
 GRAPHQL_ENDPOINT = "https://academichub-gw.azurewebsites.net/graphql"
 
 MAX_STORED_DV_ROWS = 2000000
